@@ -11,6 +11,7 @@ import {
   OneClickMode,
   ActionModel,
   ActionVariableInput,
+  ActionType,
 } from '@grafana/data';
 import { t } from '@grafana/i18n';
 import { TooltipDisplayMode } from '@grafana/schema';
@@ -34,7 +35,7 @@ import {
   removeStyles,
 } from 'app/plugins/panel/canvas/utils';
 
-import { getActions, getActionsDefaultField } from '../../actions/utils';
+import { getActions, getActionsDefaultField, isInfinityActionWithAuth } from '../../actions/utils';
 import { CanvasElementItem, CanvasElementOptions } from '../element';
 import { canvasElementRegistry } from '../registry';
 
@@ -640,8 +641,16 @@ export class ElementState implements LayerElement {
 
     if (this.options.links?.some((link) => link.oneClick === true)) {
       this.oneClickMode = OneClickMode.Link;
-    } else if (this.options.actions?.some((action) => action.oneClick === true)) {
-      this.oneClickMode = OneClickMode.Action;
+    } else if (
+      this.options.actions
+        ?.filter((action) => action.type === ActionType.Fetch || isInfinityActionWithAuth(action))
+        .some((action) => action.oneClick)
+    ) {
+      const scene = this.getScene();
+      const canExecuteActions = scene?.panel?.panelContext?.canExecuteActions;
+      const userCanExecuteActions = canExecuteActions?.() ?? false;
+
+      this.oneClickMode = userCanExecuteActions ? OneClickMode.Action : OneClickMode.Off;
     } else {
       this.oneClickMode = OneClickMode.Off;
     }
@@ -901,9 +910,17 @@ export class ElementState implements LayerElement {
   };
 
   getPrimaryAction = () => {
-    const config: ValueLinkConfig = { valueRowIndex: getRowIndex(this.data.field, this.getScene()!) };
+    const scene = this.getScene();
+    const canExecuteActions = scene?.panel?.panelContext?.canExecuteActions;
+    const userCanExecuteActions = canExecuteActions?.() ?? false;
+
+    if (!userCanExecuteActions) {
+      return undefined;
+    }
+
+    const config: ValueLinkConfig = { valueRowIndex: getRowIndex(this.data.field, scene!) };
     const actionsDefaultFieldConfig = { links: this.options.links ?? [], actions: this.options.actions ?? [] };
-    const frames = this.getScene()?.data?.series;
+    const frames = scene?.data?.series;
 
     if (frames) {
       const defaultField = getActionsDefaultField(actionsDefaultFieldConfig.links, actionsDefaultFieldConfig.actions);
@@ -922,7 +939,7 @@ export class ElementState implements LayerElement {
         frames[0],
         defaultField,
         scopedVars,
-        this.getScene()?.panel.props.replaceVariables!,
+        scene?.panel.props.replaceVariables!,
         actionsDefaultFieldConfig.actions,
         config
       );
